@@ -38,9 +38,7 @@ sub zscore {
 #-----------------------------------------------
     my $self = shift;
     my $args = Class::OOorNO::coerce_array(@_);
-    foreach (keys %{$args}) {
-        $self->{$_} = $args->{$_};
-    }
+    $self->{$_} = $args->{$_} foreach keys %{$args};
     my ($z, $p, $obs_dev, $exp_dev) = ();
     croak "Need to define observed and expected values for zscore" if !defined $self->{'observed'} || !defined $self->{'expected'};
     $obs_dev = $self->{'observed'} - $self->{'expected'};
@@ -49,7 +47,7 @@ sub zscore {
     return undef if !$exp_dev;
     $z = $obs_dev / $exp_dev;
  
-    $p = $self->z_2_p($z);
+    $p = $self->z_2_p($z, $self->{'tails'});
     $z = sprintf('%.' . $self->{'precision_s'} . 'f', $z) if $self->{'precision_s'};
     
     return wantarray ? ($z, $p, $obs_dev, $exp_dev) : $z;
@@ -61,9 +59,7 @@ sub ztest {
 #-----------------------------------------------
     my $self = shift;
     my $args = Class::OOorNO::coerce_array(@_);
-    foreach (keys %{$args}) {
-        $self->{$_} = $args->{$_};
-    }
+    $self->{$_} = $args->{$_} foreach keys %{$args};
     my ($z, $p, $obs_dev, $exp_dev) = ();
 
     $obs_dev = $self->{'observed'} - $self->{'expected'};
@@ -72,9 +68,9 @@ sub ztest {
     return undef if !$exp_dev;
     $z = $obs_dev / $exp_dev;
  
-    $p = $self->z_2_p($z);
+    $p = $self->z_2_p($z, $self->{'tails'});
     $z = sprintf('%.' . $self->{'precision_s'} . 'f', $z) if $self->{'precision_s'};
-    
+
     return wantarray ? ($z, $p, $obs_dev, $exp_dev) : $z;
 }
 *test = \&ztest;
@@ -82,10 +78,9 @@ sub ztest {
 #-----------------------------------------------
 sub z_2_p {
 #-----------------------------------------------
-    my ($self, $z) = @_;
-    ##my $p = Statistics::Distributions::uprob(abs($z));
+    my ($self, $z, $tails) = @_;
     my $p = (1 - ndtr(abs($z))); # Math::Cephes function
-    $p *= 2 if $self->{'tails'} == 2;
+    $p *= 2 if $tails and $tails == 2;
 	$p = Statistics::Distributions::precision_string($p);
     $p = 1 if $p > 1;
     $p = 0 if $p < 0;
@@ -109,7 +104,7 @@ sub p_2_z {
         $z = 0;
     }
     else {
-        $p = $p/2 if ($self->{'tails'} == 2) || ($tails and $tails == 2);
+        $p = $p/2 if $tails and $tails == 2;
         $z = abs(ndtri($p)); # Math::Cephes function
     }
 
@@ -308,7 +303,7 @@ I<Alias>: test
 
 You supply the C<observed> and c<expected> values of your statistic, and the C<variance> or C<std_dev> or just C<error> of any kind; ... and the number of C<samplings> ("sample-size", I<N>, "trials", etc.).
 
-Optionally specify a logical value for L<ccorr|ccorr> for performing the continuity-correction to the observed deviation, and a value of either 1 or 2 to specify the L<tails|tails> for reading off the probability associated with the I<z>-value.
+Optionally specify a logical value for L<ccorr|ccorr> for performing the continuity-correction to the observed deviation, and a value of either 1 or 2 to specify the L<tails|tails> for reading off the probability associated with the I<z>-value. When passed to this function, values of L<ccorr|ccorr> and L<tails|tails> become the values used in this and subsequent tests.
 
 When called in array context, returns an array consisting of the z-statistic ("standard normal deviate"), its probability, the observed deviation (the difference between the observed and expected values of your statistic), and the standard deviation (the square-root of the variance supplied).
 
@@ -328,7 +323,7 @@ I<Alias>: score
 
 You supply the C<observed> and C<expected> values of your statistic, and the C<variance> or C<std_dev> or just C<error> of any kind.
 
-Optionally specify a logical value for L<ccorr|ccorr> for performing the continuity-correction to the observed deviation, and a value of either 1 or 2 to specify the L<tails|tails> for reading off the probability associated with the I<z>-value.
+Optionally specify a logical value for L<ccorr|ccorr> for performing the continuity-correction to the observed deviation, and a value of either 1 or 2 to specify the L<tails|tails> for reading off the probability associated with the I<z>-value. When passed to this function, values of L<ccorr|ccorr> and L<tails|tails> become the values used in this and subsequent tests.
 
 When called in array context, returns an array consisting of the z-statistic ("standard score"), its probability, the observed deviation (the difference between the observed and expected values of your statistic), and the standard deviation (the square-root of the variance supplied).
 
@@ -345,10 +340,11 @@ where I<X> is the expected value (mean, etc.).
 =head3 z_2_p
 
  $p = $zed->z_2_p($z)
+ $p = $zed->z_2_p($z, 1)
 
 I<Alias>: C<z2p>, C<p_value>
 
-Send a I<z>-value, get its associated I<p>-value, 2-tailed by default. Uses L<Math::Cephes|Math::Cephes> C<ndtr>.
+Send a I<z>-value, get its associated I<p>-value, 2-tailed by default, or depending on what the value of $zed->{'tails'} is, or what is sent as the second argument, if anything. Uses L<Math::Cephes|Math::Cephes> C<ndtr>.
 
 =head3 p_2_z
 
@@ -393,7 +389,7 @@ Send a I<chi>-value, get back a I<z>-value (the square-root of the thing ...).
 
 =head2 Series testing
 
-A means to aggregate results from multiple tests is exploratively supported, but only when accessing the tests through the main Sequences package. Three methods are presently used to effect this.
+A means to aggregate results from multiple tests is supported. Three methods are presently used to effect this.
 
 =head3 series_init
 
